@@ -312,6 +312,28 @@ class TestCassette(unittest.TestCase):
         assert i is not None
         assert self.interaction is i
 
+    def test_find_match_new_episodes_with_existing_unused_interactions(self):
+        """See bug 153 in GitHub for details.
+
+        https://github.com/betamaxpy/betamax/issues/153
+        """
+        self.cassette.match_options = set(['method', 'uri'])
+        self.cassette.record_mode = 'new_episodes'
+        i = self.cassette.find_match(self.response.request)
+        assert i is not None
+        assert self.interaction is i
+
+    def test_find_match_new_episodes_with_no_unused_interactions(self):
+        """See bug 153 in GitHub for details.
+
+        https://github.com/betamaxpy/betamax/issues/153
+        """
+        self.cassette.match_options = set(['method', 'uri'])
+        self.cassette.record_mode = 'new_episodes'
+        self.interaction.used = True
+        i = self.cassette.find_match(self.response.request)
+        assert i is None
+
     def test_find_match__missing_matcher(self):
         self.cassette.match_options = set(['uri', 'method', 'invalid'])
         self.cassette.record_mode = 'none'
@@ -421,6 +443,7 @@ class TestInteraction(unittest.TestCase):
         self.interaction.replace('secret_value', '<SECRET_VALUE>')
         self.interaction.replace('foo', '<FOO>')
         self.interaction.replace('http://example.com', '<EXAMPLE_URI>')
+        self.interaction.replace('', '<IF_FAIL_THIS_INSERTS_BEFORE_AND_AFTER_EACH_CHARACTER')
 
         header = (
             self.interaction.data['request']['headers']['Authorization'][0])
@@ -473,3 +496,7 @@ class TestMockHTTPResponse(unittest.TestCase):
 
     def test_is_Message(self):
         assert isinstance(self.resp.msg, email.message.Message)
+
+    def test_close(self):
+        self.resp.close()
+        assert self.resp.isclosed() is True
